[glom/gtkapplication] AppWindow: Rename get_application() to get_appwindow().



commit b174836f38e56995382805a57220deb165e1ee1b
Author: Murray Cumming <murrayc murrayc com>
Date:   Fri Feb 10 14:24:26 2012 +0100

    AppWindow: Rename get_application() to get_appwindow().

 ChangeLog                                          |    4 ++++
 glom/base_db.cc                                    |    4 ++--
 glom/base_db_table_data.cc                         |   10 +++++-----
 glom/frame_glom.cc                                 |    6 +++---
 glom/libglom/db_utils.cc                           |    6 +++---
 glom/libglom/privs.cc                              |    4 ++--
 glom/libglom/python_embed/py_glom_relatedrecord.cc |    2 +-
 glom/mode_data/box_data_calendar_related.cc        |    6 +++---
 glom/mode_data/box_data_details.cc                 |    2 +-
 glom/mode_data/buttonglom.cc                       |    4 ++--
 glom/mode_data/buttonglom.h                        |    2 +-
 glom/mode_data/datawidget/checkbutton.cc           |    6 +++---
 glom/mode_data/datawidget/checkbutton.h            |    2 +-
 glom/mode_data/datawidget/combo.cc                 |    6 +++---
 glom/mode_data/datawidget/combo.h                  |    2 +-
 .../mode_data/datawidget/combo_as_radio_buttons.cc |    6 +++---
 glom/mode_data/datawidget/combo_as_radio_buttons.h |    2 +-
 glom/mode_data/datawidget/datawidget.cc            |   16 ++++++++--------
 glom/mode_data/datawidget/datawidget.h             |    2 +-
 glom/mode_data/datawidget/entry.cc                 |    6 +++---
 glom/mode_data/datawidget/entry.h                  |    2 +-
 glom/mode_data/datawidget/label.cc                 |    4 ++--
 glom/mode_data/datawidget/label.h                  |    2 +-
 glom/mode_data/datawidget/textview.cc              |    6 +++---
 glom/mode_data/datawidget/textview.h               |    2 +-
 glom/mode_data/db_adddel/db_adddel.cc              |   20 ++++++++++----------
 glom/mode_data/db_adddel/db_adddel.h               |    4 ++--
 glom/mode_data/flowtablewithfields.cc              |    2 +-
 .../print_layouts/window_print_layout_edit.cc      |    2 +-
 .../dialog_relationships_overview.cc               |    4 ++--
 glom/navigation/box_tables.cc                      |   12 ++++++------
 glom/python_embed/python_ui_callbacks.cc           |   10 +++++-----
 glom/show_progress_message.cc                      |    2 +-
 .../utility_widgets/canvas/canvas_image_movable.cc |    4 ++--
 glom/utility_widgets/imageglom.cc                  |   14 +++++++-------
 glom/utility_widgets/imageglom.h                   |    2 +-
 glom/utility_widgets/layoutwidgetbase.cc           |    2 +-
 glom/utility_widgets/layoutwidgetbase.h            |    2 +-
 glom/utility_widgets/layoutwidgetmenu.cc           |    2 +-
 glom/utility_widgets/notebookglom.cc               |    2 +-
 glom/utility_widgets/notebookglom.h                |    2 +-
 glom/utility_widgets/notebooklabelglom.cc          |    4 ++--
 glom/utility_widgets/notebooklabelglom.h           |    2 +-
 43 files changed, 105 insertions(+), 101 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 5aafba2..c78d66b 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,9 @@
 2012-02-10  Murray Cumming  <murrayc murrayc com>
 
+	AppWindow: Rename get_application() to get_appwindow().
+
+2012-02-10  Murray Cumming  <murrayc murrayc com>
+
 	Do not use Gtk::Main.
 
 	* glom/application.cc: create(): Call the new init_gtkmm method.
diff --git a/glom/base_db.cc b/glom/base_db.cc
index 0b6f2e6..238d450 100644
--- a/glom/base_db.cc
+++ b/glom/base_db.cc
@@ -127,7 +127,7 @@ void Base_DB::handle_error(const Glib::Exception& ex)
 
   Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   dialog.set_secondary_text(ex.what());
-  //TODO: dialog.set_transient_for(*get_application());
+  //TODO: dialog.set_transient_for(*get_appwindow());
   dialog.run();
 }
 
@@ -137,7 +137,7 @@ void Base_DB::handle_error(const std::exception& ex)
 
   Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   dialog.set_secondary_text(ex.what());
-  //TODO: dialog.set_transient_for(*get_application());
+  //TODO: dialog.set_transient_for(*get_appwindow());
 
   dialog.run();
 }
diff --git a/glom/base_db_table_data.cc b/glom/base_db_table_data.cc
index 51d8bf4..a0ba65c 100644
--- a/glom/base_db_table_data.cc
+++ b/glom/base_db_table_data.cc
@@ -113,7 +113,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
           //We need the connection when we run the script, so that the script may use it.
           // TODO: Is this function supposed to throw an exception?
-          sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_application());
+          sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
             Glib::ustring error_message; //TODO: Check this.
             const Gnome::Gda::Value value =
@@ -262,7 +262,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
     const Glib::ustring message = _("Data may not be entered into this related field, because the related record does not yet exist, and the relationship does not allow automatic creation of new related records.");
     Gtk::MessageDialog dialog(Utils::bold_message(_("Related Record Does Not Exist")), true);
     dialog.set_secondary_text(message);
-    dialog.set_transient_for(*AppWindow::get_application());
+    dialog.set_transient_for(*AppWindow::get_appwindow());
     dialog.run();
 
     //Clear the field again, discarding the entered data.
@@ -284,7 +284,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
       Gtk::MessageDialog dialog(Utils::bold_message(_("Related Record Cannot Be Created")), true);
       //TODO: This is a very complex error message:
       dialog.set_secondary_text(message);
-      dialog.set_transient_for(*AppWindow::get_application());
+      dialog.set_transient_for(*AppWindow::get_appwindow());
       dialog.run();
 
       //Clear the field again, discarding the entered data.
@@ -395,7 +395,7 @@ bool Base_DB_Table_Data::confirm_delete_record()
   const Glib::ustring message = _("Are you sure that you would like to delete this record? The data in this record will then be permanently lost.");
   Gtk::MessageDialog dialog(Utils::bold_message(_("Delete record")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
   dialog.set_secondary_text(message);
-  dialog.set_transient_for(*AppWindow::get_application());
+  dialog.set_transient_for(*AppWindow::get_appwindow());
   dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   dialog.add_button(Gtk::Stock::DELETE, Gtk::RESPONSE_OK);
 
@@ -431,7 +431,7 @@ Base_DB_Table_Data::type_signal_record_changed Base_DB_Table_Data::signal_record
 
 bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relationship>& relationship, const Gnome::Gda::Value& key_value)
 {
-  BusyCursor cursor(AppWindow::get_application());
+  BusyCursor cursor(AppWindow::get_appwindow());
 
   bool result = false;
 
diff --git a/glom/frame_glom.cc b/glom/frame_glom.cc
index 62641a4..e632e04 100644
--- a/glom/frame_glom.cc
+++ b/glom/frame_glom.cc
@@ -1773,7 +1773,7 @@ void Frame_Glom::on_developer_dialog_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Frame_Glom::on_connection_initialize_progress()
 {
-  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
@@ -1781,14 +1781,14 @@ void Frame_Glom::on_connection_initialize_progress()
 
 void Frame_Glom::on_connection_startup_progress()
 {
-  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
 
 void Frame_Glom::on_connection_cleanup_progress()
 {
-  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
diff --git a/glom/libglom/db_utils.cc b/glom/libglom/db_utils.cc
index 974fbda..db5f1e3 100644
--- a/glom/libglom/db_utils.cc
+++ b/glom/libglom/db_utils.cc
@@ -771,7 +771,7 @@ void handle_error(const Glib::Exception& ex)
   //TODO_Moved:
   //Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   //dialog.set_secondary_text(ex.what());
-  //TODO: dialog.set_transient_for(*get_application());
+  //TODO: dialog.set_transient_for(*get_appwindow());
   //dialog.run();
 }
 
@@ -782,7 +782,7 @@ void handle_error(const std::exception& ex)
  //TODO_Moved:
   //Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   //dialog.set_secondary_text(ex.what());
-  //TODO: dialog.set_transient_for(*get_application());
+  //TODO: dialog.set_transient_for(*get_appwindow());
   //dialog.run();
 }
 
@@ -815,7 +815,7 @@ type_vec_fields get_fields_for_table_from_database(const Glib::ustring& table_na
     DATAMODEL_FIELDS_COL_EXTRA = 6 // Could be auto-increment
   };
 
-  //TODO: BusyCursor busy_cursor(get_application());
+  //TODO: BusyCursor busy_cursor(get_appwindow());
 
   {
     Glib::RefPtr<Gnome::Gda::Connection> connection = get_connection();
diff --git a/glom/libglom/privs.cc b/glom/libglom/privs.cc
index d430960..7c60935 100644
--- a/glom/libglom/privs.cc
+++ b/glom/libglom/privs.cc
@@ -98,7 +98,7 @@ Glib::ustring Privs::get_default_developer_user_name(Glib::ustring& password)
 
 Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_name)
 {
-  //TODO_Moved: BusyCursor cursor(AppWindow::get_application());
+  //TODO_Moved: BusyCursor cursor(AppWindow::get_appwindow());
 
   type_vec_strings result;
 
@@ -429,7 +429,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   //TODO_Performance: There's lots of database access here.
   //We could maybe replace some with the postgres has_table_* function().
 
-  //TODO_Moved: BusyCursor cursor(AppWindow::get_application());
+  //TODO_Moved: BusyCursor cursor(AppWindow::get_appwindow());
 
   //Return a cached value if possible.
   //(If it is in the cache then it's fairly recent)
diff --git a/glom/libglom/python_embed/py_glom_relatedrecord.cc b/glom/libglom/python_embed/py_glom_relatedrecord.cc
index c6ab1d3..0706f40 100644
--- a/glom/libglom/python_embed/py_glom_relatedrecord.cc
+++ b/glom/libglom/python_embed/py_glom_relatedrecord.cc
@@ -108,7 +108,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
         builder->add_expr(m_from_key_value)));
 
     /* TODO: Fix linking problems
-    const App_Glom* app = App_Glom::get_application();
+    const App_Glom* app = App_Glom::get_appwindow();
     if(app && app->get_show_sql_debug())
     {
       try
diff --git a/glom/mode_data/box_data_details.cc b/glom/mode_data/box_data_details.cc
index b03d580..b0dd406 100644
--- a/glom/mode_data/box_data_details.cc
+++ b/glom/mode_data/box_data_details.cc
@@ -951,7 +951,7 @@ void Box_Data_Details::print_layout()
       false /* do not avoid page margins */);
   
   //Show the print preview window:
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   PrintLayoutUtils::do_print_layout(print_layout, m_found_set,
     false /* not preview */, document, true /* avoid page margins */, app);
 }
diff --git a/glom/mode_data/buttonglom.cc b/glom/mode_data/buttonglom.cc
index 04a3a0c..05b8b79 100644
--- a/glom/mode_data/buttonglom.cc
+++ b/glom/mode_data/buttonglom.cc
@@ -52,7 +52,7 @@ void ButtonGlom::init()
 
 }
 
-AppWindow* ButtonGlom::get_application()
+AppWindow* ButtonGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -84,7 +84,7 @@ void ButtonGlom::on_menu_properties_activate()
 
 bool ButtonGlom::on_button_press_event(GdkEventButton *event)
 {
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
diff --git a/glom/mode_data/buttonglom.h b/glom/mode_data/buttonglom.h
index 70d2b57..3ff812f 100644
--- a/glom/mode_data/buttonglom.h
+++ b/glom/mode_data/buttonglom.h
@@ -43,7 +43,7 @@ public:
 private:
   void init();
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 #ifndef GLOM_ENABLE_CLIENT_ONLY    
   virtual void on_menu_properties_activate();
   virtual bool on_button_press_event(GdkEventButton *event);
diff --git a/glom/mode_data/datawidget/checkbutton.h b/glom/mode_data/datawidget/checkbutton.h
index db279bc..ef68fb3 100644
--- a/glom/mode_data/datawidget/checkbutton.h
+++ b/glom/mode_data/datawidget/checkbutton.h
@@ -54,7 +54,7 @@ private:
   virtual bool on_button_press_event(GdkEventButton *event); //override
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 };
 
 } //namespace DataWidetChildren
diff --git a/glom/mode_data/datawidget/combo.h b/glom/mode_data/datawidget/combo.h
index c026e3b..ced5a6d 100644
--- a/glom/mode_data/datawidget/combo.h
+++ b/glom/mode_data/datawidget/combo.h
@@ -77,7 +77,7 @@ private:
   virtual bool on_button_press_event(GdkEventButton *event);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 
 
   Gnome::Gda::Value m_old_value; //TODO: Only useful for navigation, which currently has no implementation.
diff --git a/glom/mode_data/datawidget/combo_as_radio_buttons.h b/glom/mode_data/datawidget/combo_as_radio_buttons.h
index 8050aa6..4fc069a 100644
--- a/glom/mode_data/datawidget/combo_as_radio_buttons.h
+++ b/glom/mode_data/datawidget/combo_as_radio_buttons.h
@@ -88,7 +88,7 @@ private:
   void show_context_menu(GdkEventButton *event);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 
 
   Glib::ustring m_old_text;
diff --git a/glom/mode_data/datawidget/datawidget.h b/glom/mode_data/datawidget/datawidget.h
index e5f8f7e..305b7f5 100644
--- a/glom/mode_data/datawidget/datawidget.h
+++ b/glom/mode_data/datawidget/datawidget.h
@@ -117,7 +117,7 @@ private:
   //virtual void on_menupopup_add_item(LayoutWidgetBase::enumType item);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  AppWindow* get_application();
+  AppWindow* get_appwindow();
 
   void set_child_size_by_field(const sharedptr<const LayoutItem_Field>& field);
   int get_suitable_width(const sharedptr<const LayoutItem_Field>& field_layout);
diff --git a/glom/mode_data/datawidget/entry.h b/glom/mode_data/datawidget/entry.h
index 9390f37..4a307fb 100644
--- a/glom/mode_data/datawidget/entry.h
+++ b/glom/mode_data/datawidget/entry.h
@@ -76,7 +76,7 @@ private:
   virtual bool on_button_press_event(GdkEventButton *event); //override
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 
   Glib::ustring m_old_text;
   Field::glom_field_type m_glom_type; //Store the type so we can validate the text accordingly.
diff --git a/glom/mode_data/datawidget/label.cc b/glom/mode_data/datawidget/label.cc
index 7d435c9..4049f7f 100644
--- a/glom/mode_data/datawidget/label.cc
+++ b/glom/mode_data/datawidget/label.cc
@@ -66,7 +66,7 @@ void Label::init()
   m_label.set_line_wrap();
 }
 
-AppWindow* Label::get_application()
+AppWindow* Label::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -102,7 +102,7 @@ void Label::on_menu_properties_activate()
 
 bool Label::on_button_press_event(GdkEventButton *event)
 {
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
diff --git a/glom/mode_data/datawidget/label.h b/glom/mode_data/datawidget/label.h
index 407f04a..e1793d4 100644
--- a/glom/mode_data/datawidget/label.h
+++ b/glom/mode_data/datawidget/label.h
@@ -51,7 +51,7 @@ public:
 private:
   void init();
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
     
   Gtk::Label m_label;
 #ifndef GLOM_ENABLE_CLIENT_ONLY    
diff --git a/glom/mode_data/datawidget/textview.h b/glom/mode_data/datawidget/textview.h
index bfcf7c1..2a75529 100644
--- a/glom/mode_data/datawidget/textview.h
+++ b/glom/mode_data/datawidget/textview.h
@@ -79,7 +79,7 @@ private:
   virtual bool on_button_press_event(GdkEventButton *event); //override
 #endif
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 
   Glib::ustring m_old_text;
   Field::glom_field_type m_glom_type; //Store the type so we can validate the text accordingly.
diff --git a/glom/mode_data/flowtablewithfields.cc b/glom/mode_data/flowtablewithfields.cc
index 25937cf..ad7eaaa 100644
--- a/glom/mode_data/flowtablewithfields.cc
+++ b/glom/mode_data/flowtablewithfields.cc
@@ -1412,7 +1412,7 @@ void FlowTableWithFields::on_menu_delete_activate()
 
 bool FlowTableWithFields::on_button_press_event(GdkEventButton *event)
 {
-  AppWindow* pApp = AppWindow::get_application();
+  AppWindow* pApp = AppWindow::get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
diff --git a/glom/mode_design/print_layouts/window_print_layout_edit.cc b/glom/mode_design/print_layouts/window_print_layout_edit.cc
index adf2b47..1bc2980 100644
--- a/glom/mode_design/print_layouts/window_print_layout_edit.cc
+++ b/glom/mode_design/print_layouts/window_print_layout_edit.cc
@@ -1072,7 +1072,7 @@ void Window_PrintLayout_Edit::on_menu_file_print_preview()
   document->set_print_layout(m_table_name, print_layout);
 
   //Show the print preview window:
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->do_print_layout(m_print_layout->get_name(), true /* preview */, this);
 }
diff --git a/glom/mode_design/relationships_overview/dialog_relationships_overview.cc b/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
index 6e88803..790f434 100644
--- a/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
+++ b/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
@@ -504,7 +504,7 @@ void Dialog_RelationshipsOverview::setup_context_menu()
 
 void Dialog_RelationshipsOverview::on_context_menu_edit_fields(Glib::RefPtr<CanvasGroupDbTable> table)
 {
-  AppWindow* pApp = AppWindow::get_application();
+  AppWindow* pApp = AppWindow::get_appwindow();
   if(pApp && table)
   {
     pApp->do_menu_developer_fields(*this, table->get_table_name());
@@ -515,7 +515,7 @@ void Dialog_RelationshipsOverview::on_context_menu_edit_fields(Glib::RefPtr<Canv
 
 void Dialog_RelationshipsOverview::on_context_menu_edit_relationships(Glib::RefPtr<CanvasGroupDbTable> table)
 {
-  AppWindow* pApp = AppWindow::get_application();
+  AppWindow* pApp = AppWindow::get_appwindow();
   if(pApp && table)
   {
     pApp->do_menu_developer_relationships(*this, table->get_table_name());
diff --git a/glom/navigation/box_tables.cc b/glom/navigation/box_tables.cc
index f07f4c5..a11a3d2 100644
--- a/glom/navigation/box_tables.cc
+++ b/glom/navigation/box_tables.cc
@@ -105,7 +105,7 @@ void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const shar
 
 bool Box_Tables::fill_from_database()
 {
-  BusyCursor busy_cursor(AppWindow::get_application());
+  BusyCursor busy_cursor(AppWindow::get_appwindow());
 
   bool result = Base_DB::fill_from_database();
 
@@ -154,7 +154,7 @@ bool Box_Tables::fill_from_database()
     g_warning("Box_Tables::fill_from_database(): document is null");
 
   //Get the list of tables in the database, from the server:
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_application());
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
   if(sharedconnection)
   {
@@ -235,7 +235,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     //Ask the user if they want us to try to cope with this:
     Gtk::MessageDialog dialog(Utils::bold_message(_("Table Already Exists")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
     dialog.set_secondary_text(_("This table already exists on the database server, though it is not mentioned in the .glom file. This should not happen. Would you like Glom to attempt to use the existing table?"));
-    dialog.set_transient_for(*AppWindow::get_application());
+    dialog.set_transient_for(*AppWindow::get_appwindow());
 
     const int response = dialog.run();
     dialog.hide();
@@ -295,7 +295,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
         {
            //TODO: Do not show tables that are not in the document.
            Gtk::MessageDialog dialog(_("You cannot delete this table, because there is no information about this table in the document."));
-           dialog.set_transient_for(*AppWindow::get_application());
+           dialog.set_transient_for(*AppWindow::get_appwindow());
            dialog.run();
         }
         else
@@ -304,7 +304,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           const Glib::ustring strMsg = Glib::ustring::compose(_("Are you sure that you want to delete this table?\nTable name: %1"), table_name);
           Gtk::MessageDialog dialog(Utils::bold_message(_("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
-          dialog.set_transient_for(*AppWindow::get_application());
+          dialog.set_transient_for(*AppWindow::get_appwindow());
           const int iButtonClicked = dialog.run();
           
           //Get a list of autoincrementing fields in the table:
@@ -442,7 +442,7 @@ void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
     {
        Gtk::MessageDialog dialog(Utils::bold_message(_("Unknown Table")), true);
        dialog.set_secondary_text(_("You cannot open this table, because there is no information about this table in the document."));
-       dialog.set_transient_for(*AppWindow::get_application());
+       dialog.set_transient_for(*AppWindow::get_appwindow());
        dialog.run();
     }
     else
diff --git a/glom/python_embed/python_ui_callbacks.cc b/glom/python_embed/python_ui_callbacks.cc
index a4e6a1b..45aaaf3 100644
--- a/glom/python_embed/python_ui_callbacks.cc
+++ b/glom/python_embed/python_ui_callbacks.cc
@@ -40,35 +40,35 @@ AppPythonUICallbacks::AppPythonUICallbacks()
 
 void AppPythonUICallbacks::on_show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value)
 {
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->show_table_details(table_name, primary_key_value);
 }
 
 void AppPythonUICallbacks::on_show_table_list(const Glib::ustring& table_name)
 {
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->show_table_list(table_name);
 }
 
 void AppPythonUICallbacks::on_print_report(const Glib::ustring& report_name)
 {
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->print_report(report_name);
 }
 
 void AppPythonUICallbacks::on_print_layout()
 {
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->print_layout();
 }
 
 void AppPythonUICallbacks::on_start_new_record()
 {
-  AppWindow* app = AppWindow::get_application();
+  AppWindow* app = AppWindow::get_appwindow();
   if(app)
     app->start_new_record();
 }
diff --git a/glom/show_progress_message.cc b/glom/show_progress_message.cc
index 3ce9ee8..168e543 100644
--- a/glom/show_progress_message.cc
+++ b/glom/show_progress_message.cc
@@ -28,7 +28,7 @@ namespace Glom
 {
 
 ShowProgressMessage::ShowProgressMessage(const Glib::ustring& message)
-: m_app(dynamic_cast<AppWindow*>(AppWindow::get_application())),
+: m_app(dynamic_cast<AppWindow*>(AppWindow::get_appwindow())),
   m_message(message)
 {
   g_return_if_fail(m_app);
diff --git a/glom/utility_widgets/canvas/canvas_image_movable.cc b/glom/utility_widgets/canvas/canvas_image_movable.cc
index f250638..c559808 100644
--- a/glom/utility_widgets/canvas/canvas_image_movable.cc
+++ b/glom/utility_widgets/canvas/canvas_image_movable.cc
@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
  
-#include <glom/appwindow.h> // For get_application().
+#include <glom/appwindow.h> // For get_appwindow().
 
 #include "canvas_image_movable.h"
 #include <goocanvasmm/canvas.h>
@@ -207,7 +207,7 @@ void CanvasImageMovable::set_image_empty()
   Gtk::Widget *widget = get_canvas();
 
   if(!widget)
-    widget = AppWindow::get_application();
+    widget = AppWindow::get_appwindow();
 
   Glib::RefPtr<Gdk::Pixbuf> pixbuf;
   if(widget)
diff --git a/glom/utility_widgets/imageglom.h b/glom/utility_widgets/imageglom.h
index eec2874..76738ad 100644
--- a/glom/utility_widgets/imageglom.h
+++ b/glom/utility_widgets/imageglom.h
@@ -81,7 +81,7 @@ private:
   void on_clipboard_clear();
   void on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 
   void setup_menu_usermode();
   void show_image_data();
diff --git a/glom/utility_widgets/layoutwidgetbase.cc b/glom/utility_widgets/layoutwidgetbase.cc
index a284eb4..b5a1ad5 100644
--- a/glom/utility_widgets/layoutwidgetbase.cc
+++ b/glom/utility_widgets/layoutwidgetbase.cc
@@ -55,7 +55,7 @@ sharedptr<LayoutItem> LayoutWidgetBase::get_layout_item()
   return m_pLayoutItem;
 }
 
-AppWindow* LayoutWidgetBase::get_application() const
+AppWindow* LayoutWidgetBase::get_appwindow() const
 {
   return 0; //override to implement.
 }
diff --git a/glom/utility_widgets/layoutwidgetbase.h b/glom/utility_widgets/layoutwidgetbase.h
index 5979ccc..1918d2b 100644
--- a/glom/utility_widgets/layoutwidgetbase.h
+++ b/glom/utility_widgets/layoutwidgetbase.h
@@ -84,7 +84,7 @@ public:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 protected:
-  virtual AppWindow* get_application() const; // = 0;
+  virtual AppWindow* get_appwindow() const; // = 0;
 
 
   static void apply_formatting(Gtk::Widget& widget, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
diff --git a/glom/utility_widgets/layoutwidgetmenu.cc b/glom/utility_widgets/layoutwidgetmenu.cc
index 8e05cc9..e84585a 100644
--- a/glom/utility_widgets/layoutwidgetmenu.cc
+++ b/glom/utility_widgets/layoutwidgetmenu.cc
@@ -83,7 +83,7 @@ void LayoutWidgetMenu::setup_menu()
     sigc::mem_fun(*this, &LayoutWidgetMenu::on_menupopup_activate_delete) );
 
   //TODO: This does not work until this widget is in a container in the window:s
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
diff --git a/glom/utility_widgets/notebookglom.cc b/glom/utility_widgets/notebookglom.cc
index cdfbce6..63c0923 100644
--- a/glom/utility_widgets/notebookglom.cc
+++ b/glom/utility_widgets/notebookglom.cc
@@ -59,7 +59,7 @@ void NotebookGlom::init()
 
 }
 
-AppWindow* NotebookGlom::get_application()
+AppWindow* NotebookGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
diff --git a/glom/utility_widgets/notebookglom.h b/glom/utility_widgets/notebookglom.h
index cf4fd67..55bc0a6 100644
--- a/glom/utility_widgets/notebookglom.h
+++ b/glom/utility_widgets/notebookglom.h
@@ -48,7 +48,7 @@ protected:
 protected:
   void init();
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
 };
 
 } //namespace Glom
diff --git a/glom/utility_widgets/notebooklabelglom.cc b/glom/utility_widgets/notebooklabelglom.cc
index 123ac7b..20a19a4 100644
--- a/glom/utility_widgets/notebooklabelglom.cc
+++ b/glom/utility_widgets/notebooklabelglom.cc
@@ -61,7 +61,7 @@ void NotebookLabel::set_label (const Glib::ustring& title)
   m_label.set_label (title); 
 }
 
-AppWindow* NotebookLabel::get_application()
+AppWindow* NotebookLabel::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -149,7 +149,7 @@ void NotebookLabel::setup_menu()
 
 bool NotebookLabel::on_button_press_event(GdkEventButton *event)
 {
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
diff --git a/glom/utility_widgets/notebooklabelglom.h b/glom/utility_widgets/notebooklabelglom.h
index 3790f3b..227e29e 100644
--- a/glom/utility_widgets/notebooklabelglom.h
+++ b/glom/utility_widgets/notebooklabelglom.h
@@ -45,7 +45,7 @@ public:
 private:
   void init();
 
-  virtual AppWindow* get_application();
+  virtual AppWindow* get_appwindow();
     
   Gtk::Label m_label;
   NotebookGlom* m_notebook;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/glom/mode_data/box_data_calendar_related.cc b/glom/mode_data/box_data_calendar_related.cc
index 9c825b4..b2d1abf 100644
--- a/glom/mode_data/box_data_calendar_related.cc
+++ b/glom/mode_data/box_data_calendar_related.cc
@@ -514,7 +514,7 @@ void Box_Data_Calendar_Related::setup_menu()
     sigc::mem_fun(*this, &Box_Data_Calendar_Related::on_MenuPopup_activate_layout) );
 
   //TODO: This does not work until this widget is in a container in the window:
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -563,8 +563,8 @@ void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *e
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
diff --git a/glom/mode_data/datawidget/checkbutton.cc b/glom/mode_data/datawidget/checkbutton.cc
index a077069..3ee795e 100644
--- a/glom/mode_data/datawidget/checkbutton.cc
+++ b/glom/mode_data/datawidget/checkbutton.cc
@@ -55,8 +55,8 @@ void CheckButton::init()
 bool CheckButton::on_button_press_event(GdkEventButton *event)
 {
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -84,7 +84,7 @@ bool CheckButton::on_button_press_event(GdkEventButton *event)
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* CheckButton::get_application()
+AppWindow* CheckButton::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
diff --git a/glom/mode_data/datawidget/combo.cc b/glom/mode_data/datawidget/combo.cc
index 7941e87..d108f39 100644
--- a/glom/mode_data/datawidget/combo.cc
+++ b/glom/mode_data/datawidget/combo.cc
@@ -318,8 +318,8 @@ bool ComboGlom::on_button_press_event(GdkEventButton *event)
 g_warning("ComboGlom::on_button_press_event()");
 
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -349,7 +349,7 @@ g_warning("ComboGlom::on_button_press_event()");
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* ComboGlom::get_application()
+AppWindow* ComboGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
diff --git a/glom/mode_data/datawidget/combo_as_radio_buttons.cc b/glom/mode_data/datawidget/combo_as_radio_buttons.cc
index f95d8a4..d09c6bd 100644
--- a/glom/mode_data/datawidget/combo_as_radio_buttons.cc
+++ b/glom/mode_data/datawidget/combo_as_radio_buttons.cc
@@ -267,11 +267,11 @@ Glib::ustring ComboAsRadioButtons::get_text() const
 void ComboAsRadioButtons::show_context_menu(GdkEventButton *event)
 {
   std::cout << "ComboAsRadioButtons::show_context_menu()" << std::endl;
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     //Enable/Disable items.
     //We did this earlier, but get_application is more likely to work now:
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
     pApp->add_developer_action(m_refContextAddField);
     pApp->add_developer_action(m_refContextAddRelatedRecords);
@@ -308,7 +308,7 @@ bool ComboAsRadioButtons::on_button_press_event(GdkEventButton *event)
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* ComboAsRadioButtons::get_application()
+AppWindow* ComboAsRadioButtons::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -267,11 +267,11 @@ Glib::ustring ComboAsRadioButtons::get_text() const
   {
     //Enable/Disable items.
-    //We did this earlier, but get_application is more likely to work now:
+    //We did this earlier, but get_appwindow is more likely to work now:
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
     pApp->add_developer_action(m_refContextAddField);
diff --git a/glom/mode_data/datawidget/datawidget.cc b/glom/mode_data/datawidget/datawidget.cc
index 66b2da4..5d7380b 100644
--- a/glom/mode_data/datawidget/datawidget.cc
+++ b/glom/mode_data/datawidget/datawidget.cc
@@ -426,8 +426,8 @@ bool DataWidget::on_button_press_event(GdkEventButton *event)
   //g_warning("DataWidget::on_button_press_event_popup");
 
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -462,7 +462,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field)
 {
-  return offer_field_list(table_name, start_field, get_document(), get_application());
+  return offer_field_list(table_name, start_field, get_document(), get_appwindow());
 }
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, AppWindow* app)
@@ -504,7 +504,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
   add_view(dialog); //Give it access to the document.
   dialog->set_field(start_field, m_table_name);
 
-  Gtk::Window* parent = get_application();
+  Gtk::Window* parent = get_appwindow();
   if(parent)
     dialog->set_transient_for(*parent);
 
@@ -567,7 +567,7 @@ void DataWidget::on_child_user_requested_layout()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* DataWidget::get_application()
+AppWindow* DataWidget::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -635,7 +635,7 @@ void DataWidget::on_button_choose_date()
 
   if(dialog)
   {
-    Gtk::Window* parent = get_application(); //This doesn't work (and would be wrong) when the widget is in a Field Definitions dialog.
+    Gtk::Window* parent = get_appwindow(); //This doesn't work (and would be wrong) when the widget is in a Field Definitions dialog.
     if(parent)
       dialog->set_transient_for(*parent);
     dialog->set_date_chosen(get_value());
@@ -674,7 +674,7 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
   if(dialog)
   {
     //dialog->set_document(get_document(), table_name, field);
-    Gtk::Window* parent = get_application();
+    Gtk::Window* parent = get_appwindow();
     if(parent)
       dialog->set_transient_for(*parent);
     add_view(dialog);
@@ -723,7 +723,7 @@ bool DataWidget::offer_related_record_id_new(Gnome::Gda::Value& chosen_id)
   if(dialog)
   {
     //dialog->set_document(get_document(), table_name, field);
-    Gtk::Window* parent = get_application();
+    Gtk::Window* parent = get_appwindow();
     if(parent)
       dialog->set_transient_for(*parent);
     add_view(dialog);
diff --git a/glom/mode_data/datawidget/entry.cc b/glom/mode_data/datawidget/entry.cc
index 44803bd..08cfa07 100644
--- a/glom/mode_data/datawidget/entry.cc
+++ b/glom/mode_data/datawidget/entry.cc
@@ -191,8 +191,8 @@ Gnome::Gda::Value Entry::get_value() const
 bool Entry::on_button_press_event(GdkEventButton *event)
 {
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -222,7 +222,7 @@ bool Entry::on_button_press_event(GdkEventButton *event)
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* Entry::get_application()
+AppWindow* Entry::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
diff --git a/glom/mode_data/datawidget/textview.cc b/glom/mode_data/datawidget/textview.cc
index 2069194..4c1e925 100644
--- a/glom/mode_data/datawidget/textview.cc
+++ b/glom/mode_data/datawidget/textview.cc
@@ -177,8 +177,8 @@ Gnome::Gda::Value TextView::get_value() const
 bool TextView::on_button_press_event(GdkEventButton *event)
 {
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -208,7 +208,7 @@ bool TextView::on_button_press_event(GdkEventButton *event)
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-AppWindow* TextView::get_application()
+AppWindow* TextView::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
diff --git a/glom/mode_data/db_adddel/db_adddel.cc b/glom/mode_data/db_adddel/db_adddel.cc
index f4aef67..d0a38b9 100644
--- a/glom/mode_data/db_adddel/db_adddel.cc
+++ b/glom/mode_data/db_adddel/db_adddel.cc
@@ -126,7 +126,7 @@ DbAddDel::DbAddDel()
 DbAddDel::~DbAddDel()
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->remove_developer_action(m_refContextLayout);
@@ -251,7 +251,7 @@ void DbAddDel::setup_menu()
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_layout) );
 
   //TODO: This does not work until this widget is in a container in the window:
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -313,8 +313,8 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -1612,7 +1612,7 @@ void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColu
 
 void DbAddDel::on_treeview_column_clicked(int model_column_index)
 {
-  BusyCursor busy_cursor(get_application());
+  BusyCursor busy_cursor(get_appwindow());
 
   if(model_column_index >= (int)m_column_items.size())
     return;
@@ -2012,7 +2012,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
   }
 }
 
-AppWindow* DbAddDel::get_application()
+AppWindow* DbAddDel::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -2155,7 +2155,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
     Glib::ustring table_name = m_found_set.m_table_name;
     sharedptr<Field> primary_key_field;
     Gnome::Gda::Value primary_key_value;
-    Gtk::Window* window = get_application();
+    Gtk::Window* window = get_appwindow();
 
     //Just update the record:
     try
@@ -2303,7 +2303,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     //Tell user that they can't do that:
     Gtk::MessageDialog dialog(Utils::bold_message(_("Extra Related Records Not Possible")), true, Gtk::MESSAGE_WARNING);
     dialog.set_secondary_text(_("You attempted to add a new related record, but there can only be one related record, because the relationship uses a unique key.")),
-    dialog.set_transient_for(*AppWindow::get_application());
+    dialog.set_transient_for(*AppWindow::get_appwindow());
     dialog.run();
 
     return;
@@ -2339,7 +2339,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   if(Conversions::value_is_empty(primary_key_value))
     return;
 
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application()); //Keep it alive while we need the data_model.
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_appwindow()); //Keep it alive while we need the data_model.
   if(!sharedconnection)
   {
     //Add Record failed.
@@ -2351,7 +2351,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
 
   sharedptr<LayoutItem_Field> layout_field = sharedptr<LayoutItem_Field>::create();
   layout_field->set_full_field_details(primary_key_field);
-  if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, layout_field, primary_key_value, get_application()))
+  if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, layout_field, primary_key_value, get_appwindow()))
   {
     //Revert to a blank value.
     primary_key_value = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
diff --git a/glom/mode_data/db_adddel/db_adddel.h b/glom/mode_data/db_adddel/db_adddel.h
index 0379150..b8a041e 100644
--- a/glom/mode_data/db_adddel/db_adddel.h
+++ b/glom/mode_data/db_adddel/db_adddel.h
@@ -376,8 +376,8 @@ private:
 
   guint get_fixed_cell_height();
 
-  //TODO: Remove this and use AppGlom::get_application() instead?
-  AppWindow* get_application();
+  //TODO: Remove this and use AppGlom::get_appwindow() instead?
+  AppWindow* get_appwindow();
 
   void refresh_cell_choices_data_from_database_with_foreign_key(guint model_index, const Gnome::Gda::Value& foreign_key_value);
 
diff --git a/glom/utility_widgets/imageglom.cc b/glom/utility_widgets/imageglom.cc
index 5aa80a9..84e85c8 100644
--- a/glom/utility_widgets/imageglom.cc
+++ b/glom/utility_widgets/imageglom.cc
@@ -108,8 +108,8 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
   gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
 
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  AppWindow* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -157,7 +157,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
   return Gtk::EventBox::on_button_press_event(event);
 }
 
-AppWindow* ImageGlom::get_application()
+AppWindow* ImageGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
@@ -495,7 +495,7 @@ void ImageGlom::on_menupopup_activate_open_file()
 
 void ImageGlom::on_menupopup_activate_open_file_with()
 {
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   //Offer the user a choice of suitable applications:
   const Glib::ustring mime_type = get_mime_type();
@@ -671,7 +671,7 @@ static void set_file_filter_images(Gtk::FileChooser& file_chooser)
 
 void ImageGlom::on_menupopup_activate_save_file()
 {
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   Gtk::FileChooserDialog dialog(_("Save Image"), Gtk::FILE_CHOOSER_ACTION_SAVE);
   if(pApp)
@@ -737,7 +737,7 @@ bool ImageGlom::save_file(const Glib::ustring& uri)
   // Automatically delete the dialog when we no longer need it:
   std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog_save);
 
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
     dialog_save->set_transient_for(*pApp);
 
@@ -758,7 +758,7 @@ void ImageGlom::on_menupopup_activate_select_file()
   if(m_read_only)
     return;
     
-  AppWindow* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   Gtk::FileChooserDialog dialog(_("Choose Image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   if(pApp)